Classes
=======

For more information on the classes, refer to the `Rust documentation <https://docs.rs/splashsurf_lib/latest/splashsurf_lib/index.html>`_ of ``splashsurf_lib``.

.. currentmodule:: pysplashsurf

.. autoclass:: SphInterpolator
    :members:

    See `SphInterpolator <https://docs.rs/splashsurf_lib/latest/splashsurf_lib/sph_interpolation/struct.SphInterpolator.html>`_ for more information.

Mesh types
----------

.. autoclass:: TriMesh3d
    :members:

    See `TriMesh3d <https://docs.rs/splashsurf_lib/latest/splashsurf_lib/mesh/struct.TriMesh3d.html>`_ for more information.

.. autoclass:: MixedTriQuadMesh3d
    :members:

    See `MixedTriQuadMesh3d <https://docs.rs/splashsurf_lib/latest/splashsurf_lib/mesh/struct.MixedTriQuadMesh3d.html>`_ for more information.

.. autoclass:: MeshWithData
    :members:

    See `MeshWithData <https://docs.rs/splashsurf_lib/latest/splashsurf_lib/mesh/struct.MeshWithData.html>`_ for more information.

Helper and return types
-----------------------

.. autoclass:: Aabb3d
    :members:
    
    See `Aabb3d <https://docs.rs/splashsurf_lib/latest/splashsurf_lib/type.Aabb3d.html>`_ for more information.

.. autoclass:: MeshType
    :members:

.. autoclass:: NeighborhoodLists
    :members:

.. autoclass:: SurfaceReconstruction
    :members:

    See `SurfaceReconstruction <https://docs.rs/splashsurf_lib/latest/splashsurf_lib/struct.SurfaceReconstruction.html>`_ for more information.

.. autoclass:: UniformGrid
    :members:

    See `UniformGrid <https://docs.rs/splashsurf_lib/latest/splashsurf_lib/uniform_grid/type.UniformGrid.html>`_ for more information.

.. autoclass:: VertexVertexConnectivity
    :members: